Reference: Command-Line Interface
==========================================================================

In this section, we overview the default command-line interface

.. note::
  There is a ``ninja`` backend with similar targets but it is not as
  closely maintained as the ``make`` backend.

foo

